@@ -1,4 +1,4 @@
-bpp_1interim <- function(prior = c("normal", "flat"), datasigma, finalsigma, successmean, IntEffBoundary, 
+bpp_1interim <- function(prior = c("normal", "flat"), interimSE, finalSE, successmean, IntEffBoundary, 
                          IntFutBoundary, IntFix, priormean, propA = 0.5, thetas, ...){
   
   # list input arguments
@@ -7,7 +7,7 @@ bpp_1interim <- function(prior = c("normal", "flat"), datasigma, finalsigma, suc
   ## ------------------------------------------
   ## posterior power:
   ## ------------------------------------------
-  pp <- post_power(x = thetas, datasigma = datasigma, finalsigma = finalsigma, successmean = successmean, 
+  pp <- post_power(x = thetas, interimSE = interimSE, finalSE = finalSE, successmean = successmean, 
                    IntEffBoundary = IntEffBoundary, IntFutBoundary = IntFutBoundary)
 
   ## ------------------------------------------
@@ -16,21 +16,21 @@ bpp_1interim <- function(prior = c("normal", "flat"), datasigma, finalsigma, suc
   if (prior == "normal"){
     
     # initial BPP
-    bpp0 <- bpp(prior = "normal", successmean = successmean, finalsigma = finalsigma, priormean = priormean, priorsigma = inp$priorsigma)
+    bpp0 <- bpp(prior = "normal", successmean = successmean, finalSE = finalSE, priormean = priormean, priorsigma = inp$priorsigma)
   
     ## compute BPP after not stopping at interim:
-    bpp3 <- integrate(Vectorize(interval_toIntegrate), lower = -Inf, upper = Inf, prior = "normal", datasigma = datasigma, 
-                    finalsigma = finalsigma, successmean = successmean, IntEffBoundary = IntEffBoundary, 
-                    IntFutBoundary = IntFutBoundary, priormean = priormean, priorsigma = inp$priorsigma)$value
+    bpp3 <- integrate(Vectorize(interval_toIntegrate), lower = -Inf, upper = Inf, prior = "normal", interimSE = interimSE, 
+                    finalSE = finalSE, successmean = successmean, IntEffBoundary = IntEffBoundary, 
+                    IntFutBoundary = IntFutBoundary, priormean = priormean, priorsigma = inp$priorsigma, subdivisions = 300)$value
 
     ## posterior density after not stopping at interim, interval knowledge
     qupdate_norm3 <- integrate(interval_posterior_nominator, lower = -Inf, upper = Inf, prior = "normal", 
-                             IntEffBoundary = IntEffBoundary, IntFutBoundary = IntFutBoundary, datasigma = datasigma, 
-                             priormean = priormean, priorsigma = inp$priorsigma)$value
+                             IntEffBoundary = IntEffBoundary, IntFutBoundary = IntFutBoundary, interimSE = interimSE, 
+                             priormean = priormean, priorsigma = inp$priorsigma, subdivisions = 300)$value
     post3 <- rep(NA, length(thetas))
     for (i in 1:length(thetas)){
       post3[i] <- interval_posterior_nominator(x = thetas[i], prior = "normal", IntEffBoundary = IntEffBoundary, 
-                                                    IntFutBoundary = IntFutBoundary, datasigma = datasigma, 
+                                                    IntFutBoundary = IntFutBoundary, interimSE = interimSE, 
                                                     priormean = priormean, priorsigma = inp$priorsigma)
     }
     post3 <- post3 / qupdate_norm3
@@ -39,9 +39,9 @@ bpp_1interim <- function(prior = c("normal", "flat"), datasigma, finalsigma, suc
     bpp.fix <- rep(NA, length(IntFix))
     for (i in 1:length(bpp.fix)){
       bpp.fix[i] <- integrate(Vectorize(estimate_toIntegrate), lower = -Inf, upper = Inf, prior = "normal",
-                                successmean = successmean, finalsigma = finalsigma, datamean = IntFix[i], 
-                                datasigma = datasigma, priormean = priormean, propA = propA, 
-                                priorsigma = inp$priorsigma)$value
+                                successmean = successmean, finalSE = finalSE, interimmean = IntFix[i], 
+                                interimSE = interimSE, priormean = priormean, propA = propA, 
+                                priorsigma = inp$priorsigma, subdivisions = 300)$value
     }
   
     ## posterior density after not stopping at interim, exact knowledge
@@ -49,12 +49,12 @@ bpp_1interim <- function(prior = c("normal", "flat"), datasigma, finalsigma, suc
     post4 <- matrix(NA, ncol = length(IntFix), nrow = length(thetas))
     for (j in 1:length(IntFix)){
       qupdate_norm4.j <- integrate(estimate_posterior_nominator, lower = -Inf, upper = Inf, 
-                                 prior = "normal", datamean = IntFix[j], datasigma = datasigma, 
-                                 priormean = priormean, priorsigma = inp$priorsigma)$value
+                                 prior = "normal", interimmean = IntFix[j], interimSE = interimSE, 
+                                 priormean = priormean, priorsigma = inp$priorsigma, subdivisions = 300)$value
     post4.j <- rep(NA, length(thetas))
     for (i in 1:length(thetas)){
-      post4.j[i] <- estimate_posterior_nominator(thetas[i], prior = "normal", datamean = IntFix[j], 
-                                 datasigma = datasigma, priormean = priormean, priorsigma = inp$priorsigma)
+      post4.j[i] <- estimate_posterior_nominator(thetas[i], prior = "normal", interimmean = IntFix[j], 
+                                 interimSE = interimSE, priormean = priormean, priorsigma = inp$priorsigma)
     }
     post4.j <- post4.j / qupdate_norm4.j
     post4[, j] <- post4.j
@@ -68,21 +68,23 @@ bpp_1interim <- function(prior = c("normal", "flat"), datasigma, finalsigma, suc
   if (prior == "flat"){
     
     # initial BPP
-    bpp0 <- bpp(prior = "flat", successmean = successmean, finalsigma = finalsigma, priormean = priormean, width = inp$width, height = inp$height)
+    bpp0 <- bpp(prior = "flat", successmean = successmean, finalSE = finalSE, priormean = priormean, 
+                width = inp$width, height = inp$height)
     
     ## compute BPP after not stopping at interim:
-    bpp3 <- integrate(Vectorize(interval_toIntegrate), lower = -Inf, upper = Inf, prior = "flat", datasigma = datasigma, 
-                      finalsigma = finalsigma, successmean = successmean, IntEffBoundary = IntEffBoundary, 
-                      IntFutBoundary = IntFutBoundary, priormean = priormean, width = inp$width, height = inp$height)$value
+    bpp3 <- integrate(Vectorize(interval_toIntegrate), lower = -Inf, upper = Inf, prior = "flat", interimSE = interimSE, 
+                      finalSE = finalSE, successmean = successmean, IntEffBoundary = IntEffBoundary, 
+                      IntFutBoundary = IntFutBoundary, priormean = priormean, width = inp$width, height = inp$height, 
+                      subdivisions = 300)$value
     
     ## posterior density after not stopping at interim, interval knowledge
     qupdate_norm3 <- integrate(interval_posterior_nominator, lower = -Inf, upper = Inf, prior = "flat", 
-                               IntEffBoundary = IntEffBoundary, IntFutBoundary = IntFutBoundary, datasigma = datasigma, 
-                               priormean = priormean, width = inp$width, height = inp$height)$value
+                               IntEffBoundary = IntEffBoundary, IntFutBoundary = IntFutBoundary, interimSE = interimSE, 
+                               priormean = priormean, width = inp$width, height = inp$height, subdivisions = 300)$value
     post3 <- rep(NA, length(thetas))
     for (i in 1:length(thetas)){
       post3[i] <- interval_posterior_nominator(x = thetas[i], prior = "flat", IntEffBoundary = IntEffBoundary, 
-                                               IntFutBoundary = IntFutBoundary, datasigma = datasigma, 
+                                               IntFutBoundary = IntFutBoundary, interimSE = interimSE, 
                                                priormean = priormean, width = inp$width, height = inp$height)
     }
     post3 <- post3 / qupdate_norm3
@@ -91,9 +93,9 @@ bpp_1interim <- function(prior = c("normal", "flat"), datasigma, finalsigma, suc
     bpp.fix <- rep(NA, length(IntFix))
     for (i in 1:length(bpp.fix)){
       bpp.fix[i] <- integrate(Vectorize(estimate_toIntegrate), lower = -Inf, upper = Inf, prior = "flat",
-                              successmean = successmean, finalsigma = finalsigma, datamean = IntFix[i], 
-                              datasigma = datasigma, priormean = priormean, propA = propA, 
-                              width = inp$width, height = inp$height)$value
+                              successmean = successmean, finalSE = finalSE, interimmean = IntFix[i], 
+                              interimSE = interimSE, priormean = priormean, propA = propA, 
+                              width = inp$width, height = inp$height, subdivisions = 300)$value
     }
     
     ## posterior density after not stopping at interim, exact knowledge
@@ -101,12 +103,12 @@ bpp_1interim <- function(prior = c("normal", "flat"), datasigma, finalsigma, suc
     post4 <- matrix(NA, ncol = length(IntFix), nrow = length(thetas))
     for (j in 1:length(IntFix)){
       qupdate_norm4.j <- integrate(estimate_posterior_nominator, lower = -Inf, upper = Inf, 
-                                   prior = "flat", datamean = IntFix[j], datasigma = datasigma, 
-                                   priormean = priormean, width = inp$width, height = inp$height)$value
+                                   prior = "flat", interimmean = IntFix[j], interimSE = interimSE, 
+                                   priormean = priormean, width = inp$width, height = inp$height, subdivisions = 300)$value
       post4.j <- rep(NA, length(thetas))
       for (i in 1:length(thetas)){
-        post4.j[i] <- estimate_posterior_nominator(thetas[i], prior = "flat", datamean = IntFix[j], 
-                                                   datasigma = datasigma, priormean = priormean, 
+        post4.j[i] <- estimate_posterior_nominator(thetas[i], prior = "flat", interimmean = IntFix[j], 
+                                                   interimSE = interimSE, priormean = priormean, 
                                                    width = inp$width, height = inp$height)
       }
       post4.j <- post4.j / qupdate_norm4.j
@@ -120,11 +122,11 @@ bpp_1interim <- function(prior = c("normal", "flat"), datasigma, finalsigma, suc
   ## output
   ## ------------------------------------------
   res <- list("initial BPP" = bpp0, 
+              "conditional power interval" = pp,
               "BPP after not stopping at interim interval" = bpp3, 
               "BPP after not stopping at interim exact" = rbind(IntFix, bpp.fix),
-              "posterior density interval" = post3, 
-              "posterior power interval" = pp,
-              "posterior density exact" = post4
+              "posterior density exact" = post4,
+              "posterior density interval" = post3
   )
   return(res)
 }
