@@ -3,8 +3,9 @@ pUniformNormalTails <- function(x, mu, width, height){
   res <- rep(NA, length(x))
   
   for (i in 1:length(res)){
-    res[i] <- integrate(dUniformNormalTails, lower = -Inf, upper = x, mu = mu, width = width, height = height)$value
+    res[i] <- integrate(dUniformNormalTails, lower = -Inf, upper = x, mu = mu, width = width, height = height, 
+    subdivisions = 300)$value
     }
   
   return(res)
-}
\ No newline at end of file
+}
